@@ -2,6 +2,7 @@
 #include "Appl.hpp"
 #include "Clut.hpp"
 #include <string.h>
+#include <memory.h>
 
 extern CApplication *gApplication;
 extern CSystem	*gSystem;
@@ -263,6 +264,7 @@ void	CMaskedShape::RenderShapeClipped(short x, short y, tRect *sClipRect, short
 
 	// set up the counters
 	yCount = 0;
+	xCount = 0;
 	// determine characteristics about the pixmap
 
 	rowStart = surface->GetSurfacePtr(&pitch);
